环境要求
========
1. cinder-backup服务所在节点需要与存储之间管理网络互通，数据网络互通。
2. 存储在使用前，需要完成初始化，池的创建。需要在存储上创建共享目录，创建NFS共享, 并提前挂载到备份服务所在节点，供元数据备份使用。
3. 存储上的备份卷的名称使用到了备份时的时间戳来进行命名，并表示先后关系，因此cinder-backup节点的时间要提前同步好，避免后期再同步时间对系统造成影响。
4. cinder-backup在创建backup时，所带的数据时间戳可能与数据库中存的时间戳有差异（数据库中单位为秒，代码中的单位为微妙）导致插件处理异常，因此需要修改cinder-backup api中的代码，当存入数据库以后，backup对象再从数据库中取出来，不能直接使用原来的backup对象。如下
```
diff --git a/cinder/backup/api.py b/cinder/backup/api.py
index c11e655..10f0639 100644
--- a/cinder/backup/api.py
+++ b/cinder/backup/api.py
@@ -317,6 +317,9 @@ class API(base.Base):
             }
             backup = objects.Backup(context=context, **kwargs)
             backup.create()
+
+            backup = objects.Backup.get_by_id(context, backup.id)
+
             if not snapshot_id:
                 backup.data_timestamp = backup.created_at
                 backup.save()

```

使用说明
========
1. 部署时需要将插件拷贝到如下驱动路径
```
cp -rf cinder/backup/drivers/inspur [PATH/TO/CINDER/SERVICE]/backup/drivers/
```

2. 支持如下配置参数

选项 | 说明 | 默认值
-----|------|-------
instorage_backup_ip | 存储管理IP |
instorage_backup_port | 存储ssh服务端口 | 22
instorage_backup_login | 存储管理员账号 |
instorage_backup_password | 存储管理员账号密码 |
instorage_backup_pool | 备份卷所在的存储池 |
instorage_backup_iogrp | 备份卷所使用的IO组 | 系统默认IO组
instorage_backup_link_protocol |　备份卷挂载到主机端时的链路类型，iscsi或fibre_channel |
instorage_backup_initial_size | 备份卷的初始容量 | 默认为源卷容量的2%
instorage_backup_transmit_chunk_size | 差异数据比较的数据块大小，单位为KiB，取值为32, 64, 128, 256 | 默认256
instorage_backup_use_multipath | 备份卷挂载到主机端时，使用多路径设备来执行IO | False
instorage_backup_meta_mount_base | 元数据备份时，存储NFS共享在主机上的挂载点目录 |

3. 具体配置
修改/etc/cinder/cinder.conf配置文件，在[DEFALUT]配置组中增加备份相关配置。如下所示：
```
[DEFAULT]
backup_driver = cinder.backup.drivers.inspur.instorage.instorage.InStorageBackupDriver
instorage_backup_ip = 10.0.0.1
instorage_backup_login = <username>
instorage_backup_password = <password>
instorage_backup_pool = Pool0
instorage_backup_link_protocol=iscsi
instorage_backup_meta_mount_base = <base directory of NFS mount point>
```
